==> redturtle.custommenu.factories-0.3.0.zip: redturtle.custommenu.factories-0.3.0/setup.py <==
from setuptools import setup, find_packages
import os

version = '0.3.0'

tests_require=['zope.testing', 'Products.PloneTestCase']

setup(name='redturtle.custommenu.factories',
      version=version,
      description="Customize the Plone \"add portal content\" menu",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Plone :: 3.3",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.1",
        "Framework :: Plone :: 4.2",
        "Framework :: Plone :: 4.3",
        "Programming Language :: Python",
        "Development Status :: 4 - Beta",
        ],
      keywords='plone menu factories customize',
      author='keul',
      author_email='luca@keul.it',
      url='http://plone.org/products/redturtle.custommenu.factories',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['redturtle', 'redturtle.custommenu'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'redturtle.custommenu.factories.tests.test_doctest.test_suite',
      entry_points="""
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )

==> redturtle.custommenu.factories-0.3.1.zip: redturtle.custommenu.factories-0.3.1/setup.py <==
from setuptools import setup, find_packages
import os

version = '0.3.1'

tests_require=['zope.testing', 'Products.PloneTestCase']

setup(name='redturtle.custommenu.factories',
      version=version,
      description="Customize the Plone \"add portal content\" menu",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.rst")).read(),
      # Get more strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Plone :: 3.3",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.1",
        "Framework :: Plone :: 4.2",
        "Framework :: Plone :: 4.3",
        "Programming Language :: Python",
        "Development Status :: 5 - Production/Stable",
        ],
      keywords='plone menu factories customize',
      author='keul',
      author_email='luca@keul.it',
      url='http://plone.org/products/redturtle.custommenu.factories',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['redturtle', 'redturtle.custommenu'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      tests_require=tests_require,
      extras_require=dict(test=tests_require),
      test_suite = 'redturtle.custommenu.factories.tests.test_doctest.test_suite',
      entry_points="""
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )
